@@ -37,11 +37,11 @@ App::GitHooks - Extensible plugins system for git hooks.
 
 =head1 VERSION
 
-Version 1.7.3
+Version 1.8.0
 
 =cut
 
-our $VERSION = '1.7.3';
+our $VERSION = '1.8.0';
 
 
 =head1 DESCRIPTION
@@ -78,7 +78,7 @@ Install this distribution (with cpanm or your preferred CPAN client):
 
 =item 2.
 
-Install the plugins you are interested in (with cpanmor your prefered CPAN
+Install the plugins you are interested in (with cpanm or your prefered CPAN
 client), as C<App::GitHooks> does not bundle them. See the list of plugins
 below, but for example:
 
@@ -969,6 +969,30 @@ sub get_repository
 }
 
 
+=head2 get_remote_name()
+
+Get the name of the repository.
+
+	my $remote_name = $app->get_remote_name();
+
+=cut
+
+sub get_remote_name
+{
+	my ( $app ) = @_;
+	my $repository = $app->get_repository();
+
+	# Retrieve the remote path.
+	my $remote = $repository->run( qw( config --get remote.origin.url ) ) // '';
+
+	# Extract the remote name.
+	my ( $remote_name ) = ( $remote =~ /\/(.*?)\.git$/i );
+	$remote_name //= '(no remote found)';
+
+	return $remote_name;
+}
+
+
 =head2 get_hook_name
 
 Return the name of the git hook that called the current instance.
@@ -1177,18 +1201,14 @@ C<< <aubertg at cpan.org> >>.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2013-2015 Guillaume Aubert.
+Copyright 2013-2016 Guillaume Aubert.
 
-This program is free software: you can redistribute it and/or modify it under
-the terms of the GNU General Public License version 3 as published by the Free
-Software Foundation.
+This code is free software; you can redistribute it and/or modify it under the
+same terms as Perl 5 itself.
 
 This program is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
-PARTICULAR PURPOSE. See the GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License along with
-this program. If not, see http://www.gnu.org/licenses/
+PARTICULAR PURPOSE. See the LICENSE file for more details.
 
 =cut
 
