@@ -17,6 +17,7 @@ use File::Temp;
 use Path::Tiny qw();
 use Test::Exception;
 use Test::Git;
+use Test::Requires::Git -nocheck;
 use Test::More;
 
 # Internal dependencies.
@@ -32,11 +33,11 @@ App::GitHooks::Test - Shared test functions for App::GitHooks.
 
 =head1 VERSION
 
-Version 1.7.3
+Version 1.8.0
 
 =cut
 
-our $VERSION = '1.7.3';
+our $VERSION = '1.8.0';
 
 our @EXPORT_OK = qw(
 	ok_add_file
@@ -244,7 +245,7 @@ sub ok_setup_repository
 			# Create a temporary repository.
 			ok(
 				defined(
-					$repository = test_repository(
+					$repository = Test::Git::test_repository(
 						temp => [ CLEANUP => $cleanup_test_repository ],
 					)
 				),
@@ -557,7 +558,7 @@ sub test_hook
 		if $hook_name !~ /^[\w-]+$/;
 
 	# Bail out if Git isn't available.
-	has_git( '1.7.4.1' );
+	Test::Requires::Git::test_requires_git( '1.7.4.1' );
 	plan( tests => scalar( @$tests ) );
 
 	foreach my $test ( @$tests )
@@ -665,18 +666,14 @@ C<< <aubertg at cpan.org> >>.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2013-2015 Guillaume Aubert.
+Copyright 2013-2016 Guillaume Aubert.
 
-This program is free software: you can redistribute it and/or modify it under
-the terms of the GNU General Public License version 3 as published by the Free
-Software Foundation.
+This code is free software; you can redistribute it and/or modify it under the
+same terms as Perl 5 itself.
 
 This program is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
-PARTICULAR PURPOSE. See the GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License along with
-this program. If not, see http://www.gnu.org/licenses/
+PARTICULAR PURPOSE. See the LICENSE file for more details.
 
 =cut
 
